local function HookArenaUI()
    hooksecurefunc("ArenaEnemyFrame_Unlock",function(self)
        local color=RAID_CLASS_COLORS[select(2,UnitClass(self.unit)) or ""];
        if color then
            self.healthbar:SetStatusBarColor(color.r,color.g,color.b);
            self.healthbar.lockColor=true;
        end
    end);
end

if IsAddOnLoaded("Blizzard_ArenaUI") then
    HookArenaUI();
else
    local hookframe=CreateFrame("Frame");
    hookframe:RegisterEvent("ADDON_LOADED");
    hookframe:SetScript("OnEvent",function(self,event,arg)
        if arg=="Blizzard_ArenaUI" then
            self:UnregisterEvent(event);
            self:SetScript("OnEvent",nil);
            HookArenaUI();
        end
    end);
end
  		
---------------------------------------------------
-- CONFIGURATION -> config.lua
-- NOT HERE!
---------------------------------------------------
local config = whoaUnitFrames.config
local _, class = UnitClass("player")
local classcolor = RAID_CLASS_COLORS[select(2, UnitClass("player"))]
local color = nil
local h, hMax, hPercent, m, mMax, mPercent = 0

---------------------------------------------------
-- DK RUNES
---------------------------------------------------
if class == "DEATHKNIGHT" then
    RuneButtonIndividual1:ClearAllPoints()
    RuneButtonIndividual1:SetPoint("TOPLEFT", PlayerFrameManaBar, "BOTTOMLEFT", -1, -5)
end

---------------------------------------------------
-- PARTY
---------------------------------------------------
local function whoa_partyMembersChanged()
    local partyMembers = GetNumPartyMembers()
    if not InCombatLockdown() and partyMembers > 0 then
        for i = 1, partyMembers do
            color = RAID_CLASS_COLORS[select(2, UnitClass("party"..i))]
            if color then
                _G["PartyMemberFrame"..i.."HealthBar"]:SetStatusBarColor(color.r, color.g, color.b)
                _G["PartyMemberFrame"..i.."HealthBar"].lockColor = true
            end
            if config.repositionPartyText then
                _G["PartyMemberFrame"..i.."HealthBarText"]:ClearAllPoints()
                _G["PartyMemberFrame"..i.."HealthBarText"]:SetPoint("LEFT", _G["PartyMemberFrame"..i.."HealthBar"], "RIGHT", 0, 0)
                _G["PartyMemberFrame"..i.."ManaBarText"]:ClearAllPoints()
                _G["PartyMemberFrame"..i.."ManaBarText"]:SetPoint("LEFT", _G["PartyMemberFrame"..i.."ManaBar"], "RIGHT", 0, 0)
            end    
        end
    end
end

---------------------------------------------------
-- PLAYERFRAME
---------------------------------------------------
local function whoa_playerFrame()
    if not UnitHasVehicleUI("player") then
        PlayerName:SetWidth(0.01)
        PlayerPVPIcon:SetAlpha(0)
		PlayerFrameGroupIndicatorText:Hide()
        --PlayerFrameGroupIndicatorText:SetPoint("BOTTOMLEFT", PlayerFrame, "TOP", 0, -20)
        PlayerFrameGroupIndicatorLeft:Hide()
        PlayerFrameGroupIndicatorMiddle:Hide()
        PlayerFrameGroupIndicatorRight:Hide()
        PlayerFrameHealthBar:ClearAllPoints()
        PlayerFrameHealthBar:SetPoint("TOPLEFT", 106, -24)
        PlayerFrameHealthBar:SetHeight(26)
       
		if classcolor and config.classColorPlayer then
            PlayerFrameHealthBar:SetStatusBarColor(classcolor.r, classcolor.g, classcolor.b)
            PlayerFrameHealthBar.lockColor = true
        else
            color = FACTION_BAR_COLORS[8] -- 8 is exalted
            if color then
                PlayerFrameHealthBar:SetStatusBarColor(color.r, color.g, color.b)
                PlayerFrameHealthBar.lockColor = true
            end
        end
        
        PlayerFrameManaBar:ClearAllPoints()
        PlayerFrameManaBar:SetPoint("TOPLEFT", 106, -52)
        PlayerFrameManaBar:SetHeight(13)
      
    else
        if config.classColorPlayer then
            color = FACTION_BAR_COLORS[8] -- 8 is exalted
            if color then
                PlayerFrameHealthBar:SetStatusBarColor(color.r, color.g, color.b)
                PlayerFrameHealthBar.lockColor = true
            end
        end
        PlayerFrameHealthBar:SetHeight(12)
        PlayerFrameManaBar:SetHeight(12)
    
       
        
    end
end
hooksecurefunc("PlayerFrame_UpdateArt", whoa_playerFrame)
hooksecurefunc("PlayerFrame_SequenceFinished", whoa_playerFrame)


---------------------------------------------------
-- TARGETFRAME
---------------------------------------------------

local function whoa_targetFrame()
    TargetFrame.nameBackground:Hide()
    TargetFrameTextureFramePVPIcon:SetAlpha(0)
	TargetFrame.deadText:ClearAllPoints()
    TargetFrame.deadText:SetPoint("CENTER", TargetFrameHealthBar, "CENTER", 0, 0)
    TargetFrameTextureFrameName:ClearAllPoints()
    TargetFrameTextureFrameName:SetPoint("BOTTOMRIGHT", TargetFrame, "TOP", 0, -20)
    TargetFrameHealthBar:ClearAllPoints()
    TargetFrameHealthBar:SetPoint("TOPLEFT", 5, -24)
    TargetFrameHealthBar:SetHeight(26)
    TargetFrameManaBar:ClearAllPoints()
    TargetFrameManaBar:SetPoint("TOPLEFT", 5, -52)
    TargetFrameManaBar:SetHeight(13)
    
    TargetFrame.threatNumericIndicator:SetPoint("BOTTOM", PlayerFrame, "TOP", 75, -22)
end

local function whoa_targetChanged()
    if UnitIsPlayer("target") and config.classColorTarget then
        color = RAID_CLASS_COLORS[select(2, UnitClass("target"))]
    else
        color = FACTION_BAR_COLORS[UnitReaction("target", "player")]
    end
    if ( not UnitPlayerControlled("target") and UnitIsTapped("target") and not UnitIsTappedByPlayer("target") and not UnitIsTappedByAllThreatList("target") ) then
        TargetFrameHealthBar:SetStatusBarColor(0.5, 0.5, 0.5)
    else
        if color then
            TargetFrameHealthBar:SetStatusBarColor(color.r, color.g, color.b)
            TargetFrameHealthBar.lockColor = true
        end
    end
end

-- Code from Blizzards TargetFrame.lua
function whoa_targetUpdateAuraPositions(self, auraName, numAuras, numOppositeAuras, largeAuraList, updateFunc, maxRowWidth, offsetX)
    -- aura positioning constants
    local AURA_OFFSET_Y = 3;
    local LARGE_AURA_SIZE = config.largeAuraSize;
    local SMALL_AURA_SIZE = config.smallAuraSize;
--  local AURA_ROW_WIDTH = 122;
--  local NUM_TOT_AURA_ROWS = 3;
    local size;
    local offsetY = AURA_OFFSET_Y;
    local rowWidth = 0;
    local firstBuffOnRow = 1;
    for i=1, numAuras do
        if ( largeAuraList[i] ) then
            size = LARGE_AURA_SIZE;
            offsetY = AURA_OFFSET_Y + AURA_OFFSET_Y;
        else
            size = SMALL_AURA_SIZE;
        end
        if ( i == 1 ) then
            rowWidth = size;
            self.auraRows = self.auraRows + 1;
        else
            rowWidth = rowWidth + size + offsetX;
        end
        if ( rowWidth > maxRowWidth ) then
            updateFunc(self, auraName, i, numOppositeAuras, firstBuffOnRow, size, offsetX, offsetY);
            rowWidth = size;
            self.auraRows = self.auraRows + 1;
            firstBuffOnRow = i;
            offsetY = AURA_OFFSET_Y;
--          if ( self.auraRows > NUM_TOT_AURA_ROWS ) then
--              maxRowWidth = AURA_ROW_WIDTH;
--          end
        else
            updateFunc(self, auraName, i, numOppositeAuras, i - 1, size, offsetX, offsetY);
        end
    end
end
hooksecurefunc("TargetFrame_UpdateAuraPositions", whoa_targetUpdateAuraPositions)

---------------------------------------------------
-- FOCUSFRAME
---------------------------------------------------
local function whoa_focusFrame()
    FocusFrame:ClearAllPoints()
	FocusFrame:SetPoint("CENTER", UIParent, "CENTER", -310, 100)
	FocusFrame.nameBackground:Hide()
    FocusFrame.deadText:ClearAllPoints()
    FocusFrame.deadText:SetPoint("CENTER", FocusFrameHealthBar, "CENTER", 0, 0)
    FocusFrameTextureFrameName:ClearAllPoints()
    FocusFrameHealthBar:ClearAllPoints()
    FocusFrameHealthBar:SetPoint("TOPLEFT", 5, -24)
    FocusFrameHealthBar:SetHeight(26)
    FocusFrameManaBar:ClearAllPoints()
    FocusFrameManaBar:SetPoint("TOPLEFT", 5, -52)
    FocusFrameManaBar:SetHeight(13)
    FocusFrame.threatNumericIndicator:SetWidth(0.01)
    FocusFrame.threatNumericIndicator.bg:Hide()
    FocusFrame.threatNumericIndicator.text:Hide()
	FocusFrameTextureFrameName:ClearAllPoints()
    FocusFrameTextureFrameName:SetPoint("BOTTOMRIGHT", FocusFrame, "TOP", 0, -20)
	FocusFrameTextureFrameHealthBarText:ClearAllPoints()
    FocusFrameTextureFrameHealthBarText:SetPoint("CENTER", FocusFrameHealthBar, "CENTER", 0, 0)
    FocusFrameTextureFrameManaBarText:ClearAllPoints()
    FocusFrameTextureFrameManaBarText:SetPoint("CENTER", FocusFrameManaBar, "CENTER", 0, 0)
end

local function whoa_focusChanged()
    if UnitIsPlayer("focus") and config.classColorFocus then
        color = RAID_CLASS_COLORS[select(2, UnitClass("focus"))]
    else
        color = FACTION_BAR_COLORS[UnitReaction("focus", "player")]
    end
    if ( not UnitPlayerControlled("focus") and UnitIsTapped("focus") and not UnitIsTappedByPlayer("focus") and not UnitIsTappedByAllThreatList("focus") ) then
        FocusFrameHealthBar:SetStatusBarColor(0.5, 0.5, 0.5)
    else
        if color then
            FocusFrameHealthBar:SetStatusBarColor(color.r, color.g, color.b)
            FocusFrameHealthBar.lockColor = true
        end
	end
end
---------------------------------------------------
-- TARGETFRAME OF TARGET
---------------------------------------------------
local function whoa_targetoftargetFrame()
    TargetFrameToTHealthBar:ClearAllPoints()
    TargetFrameToTHealthBar:SetPoint("TOPLEFT", 44, -15)
    TargetFrameToTHealthBar:SetHeight(10)
    TargetFrameToTManaBar:ClearAllPoints()
    TargetFrameToTManaBar:SetPoint("TOPLEFT", 44, -25)
    TargetFrameToTManaBar:SetHeight(4)
    
   
end

---------------------------------------------------
-- TARGETFRAME OF TARGET
---------------------------------------------------
local function whoa_focustargetFrame()
    FocusFrameToTHealthBar:ClearAllPoints()
    FocusFrameToTHealthBar:SetPoint("TOPLEFT", 45, -15)
    FocusFrameToTHealthBar:SetHeight(10)
    FocusFrameToTManaBar:ClearAllPoints()
    FocusFrameToTManaBar:SetPoint("TOPLEFT", 45, -25)
    FocusFrameToTManaBar:SetHeight(4)
    
   
end


---------------------------------------------------
-- PARTYFRAMES 
---------------------------------------------------
local function whoa_partyFrame()
    for i=1,4 do
    
    _G["PartyMemberFrame"..i.."HealthBar"]:ClearAllPoints()
    _G["PartyMemberFrame"..i.."HealthBar"]:SetPoint("TOPLEFT", 45, -13)
	_G["PartyMemberFrame"..i.."HealthBar"]:SetHeight(10)
	_G["PartyMemberFrame"..i.."ManaBar"]:ClearAllPoints()
	_G["PartyMemberFrame"..i.."ManaBar"]:SetPoint("TOPLEFT", 45, -25)
	_G["PartyMemberFrame"..i.."ManaBar"]:SetHeight(4)
	end
	
end
hooksecurefunc("PartyMemberFrame_UpdateArt", whoa_partyFrame)

---------------------------------------------------
-- TEXTE
---------------------------------------------------
local function whoa_createFrame(name, parent, point, xOffset, yOffset, width, alignment)
    local f = CreateFrame("Frame", name, parent)
    f:SetPoint(point, parent, point, xOffset, yOffset)
    f:SetWidth(width)
    f:SetHeight(20)
    f.text = f:CreateFontString(name.."text", "OVERLAY")
    f.text:SetAllPoints(f)
    f.text:SetFontObject(TextStatusBarText)
    f.text:SetJustifyH(alignment)
end

whoa_createFrame("fplayerdead",        PlayerFrameHealthBar, "CENTER",  0, 0, 200, "CENTER")
whoa_createFrame("fplayerpercent",     PlayerFrameHealthBar, "LEFT",    0, 0,  40, "RIGHT")
whoa_createFrame("fplayerhealth",      PlayerFrameHealthBar, "RIGHT",  -5, 0,  75, "RIGHT")
whoa_createFrame("fplayermanapercent", PlayerFrameManaBar,   "LEFT",    0, 0,  40, "RIGHT")
whoa_createFrame("fplayermana",        PlayerFrameManaBar,   "RIGHT",  -5, 0,  75, "RIGHT")

whoa_createFrame("ftargetdead",        TargetFrameHealthBar, "CENTER",  0, 0, 200, "CENTER")
whoa_createFrame("ftargetoffline",     TargetFrameManaBar,   "CENTER",  0, 0, 200, "CENTER")
whoa_createFrame("ftargetpercent",     TargetFrameHealthBar, "LEFT",   -5, 0,  40, "RIGHT")
whoa_createFrame("ftargethealth",      TargetFrameHealthBar, "RIGHT",  -5, 0,  75, "RIGHT")
whoa_createFrame("ftargetmanapercent", TargetFrameManaBar,   "LEFT",   	0, 0,  40, "RIGHT")
whoa_createFrame("ftargetmana",        TargetFrameManaBar,   "RIGHT",  -5, 0,  75, "RIGHT")

whoa_createFrame("ffocusdead",         FocusFrameHealthBar,  "CENTER",  0, 0, 200, "CENTER")
whoa_createFrame("ffocusoffline",      FocusFrameManaBar,    "CENTER",  0, 0, 200, "CENTER")
whoa_createFrame("ffocuspercent",      FocusFrameHealthBar,  "LEFT",   -5, 0,  40, "RIGHT")
whoa_createFrame("ffocushealth",       FocusFrameHealthBar,  "RIGHT",  -5, 0,  75, "RIGHT")
whoa_createFrame("ffocusmanapercent",  FocusFrameManaBar,    "LEFT",  	0, 0,  40, "RIGHT")
whoa_createFrame("ffocusmana",         FocusFrameManaBar,    "RIGHT",  -5, 0,  75,  "RIGHT")


local function whoa_round(n, dp)
    return math.floor((n * 10^dp) + .5) / (10^dp)
end

local function whoa_format(n)
    local strLen = strlen(n)
    if not config.customStatusText then
        return n
    end
--  if config.simpleHealth and n > 999999999 then
    if config.simpleHealth and strLen > 9 then
        return whoa_round(n/1e9, 1)..config.phrases["giga"]
--  elseif config.simpleHealth and n > 999999 then
    elseif config.simpleHealth and strLen > 6 then
        return whoa_round(n/1e6, 1)..config.phrases["mega"]
--  elseif config.simpleHealth and strLen > 5 then -- no simpleHealth under 100.000
    elseif config.simpleHealth and n > 199999 then -- no simpleHealth under 199.999
        return whoa_round(n/1e3, 0)..config.phrases["kilo"]
    elseif config.thousandSeparators then
        local left, num, right = string.match(n, '^([^%d]*%d)(%d*)(.-)')
        return left..(num:reverse():gsub('(%d%d%d)', '%1'..config.phrases["1000 separator"]):reverse())..right
    else
        return n
    end
end

local function whoa_unitText(unit)
    if config.customStatusText and (unit == "player" or unit == "target" or unit == "focus") then
        h = UnitHealth(unit)
        if UnitIsDeadOrGhost(unit) then
            _G["f"..unit.."health"]:Hide()
            _G["f"..unit.."percent"]:Hide()
            _G["f"..unit.."dead"]:Show()
            if UnitIsGhost(unit) then
                _G["f"..unit.."dead"].text:SetText(config.phrases["Ghost"])
            else
                _G["f"..unit.."dead"].text:SetText(config.phrases["Dead"])
            end
        else
            _G["f"..unit.."dead"]:Hide()
            if (unit == "player" and GetCVarBool("playerStatusText")) or (not (unit == "player") and GetCVarBool("targetStatusText")) then
                _G["f"..unit.."health"]:Show()
                _G["f"..unit.."health"].text:SetText(whoa_format(h))
                if GetCVarBool("statusTextPercentage") then
                    hMax = UnitHealthMax(unit)
                    hPercent = math.floor((h / hMax) * 100)
                    _G["f"..unit.."percent"]:Show()
                    _G["f"..unit.."percent"].text:SetText(hPercent.."%")
                else
                    _G["f"..unit.."percent"]:Hide()
                end
            else
                _G["f"..unit.."health"]:Hide()
                _G["f"..unit.."percent"]:Hide()
            end
        end
        m = UnitPower(unit)
        if m > 0 then
            if UnitIsDeadOrGhost(unit) then
                _G["f"..unit.."mana"]:Hide()
                _G["f"..unit.."manapercent"]:Hide()
            elseif (unit == "player" and GetCVarBool("playerStatusText")) or (not (unit == "player") and GetCVarBool("targetStatusText")) then
                _G["f"..unit.."mana"]:Show()
                _G["f"..unit.."mana"].text:SetText(whoa_format(m))
                local showManaPercent = false
                if config.autoManaPercent then
                    if UnitPowerType(unit) == 0 then
                        showManaPercent = true
                    end
                end
                if GetCVarBool("statusTextPercentage") and showManaPercent then
                    mMax = UnitPowerMax(unit)
                    mPercent = math.floor((m / mMax) * 100)
                    _G["f"..unit.."manapercent"]:Show()
                    _G["f"..unit.."manapercent"].text:SetText(mPercent.."%")
                else
                    _G["f"..unit.."manapercent"]:Hide()
                end
            else
                _G["f"..unit.."mana"]:Hide()
                _G["f"..unit.."manapercent"]:Hide()
            end
        else
            _G["f"..unit.."mana"]:Hide()
            _G["f"..unit.."manapercent"]:Hide()
        end
        if unit == "target" or unit == "focus" then
            if UnitIsConnected(unit) then
                _G["f"..unit.."offline"]:Hide()
            else
                _G["f"..unit.."offline"]:Show()
                _G["f"..unit.."mana"]:Hide()
                _G["f"..unit.."manapercent"]:Hide()
            end
        end
    end
end

---------------------------------------------------
-- CVAR_UPDATES
---------------------------------------------------
if config.customStatusText then
    function PlayerFrameHealthBarText:Show() end
    function PlayerFrameManaBarText:Show() end
    function TargetFrameTextureFrameHealthBarText:Show() end
    function TargetFrameTextureFrameManaBarText:Show() end
    function FocusFrameTextureFrameHealthBarText:Show() end
    function FocusFrameTextureFrameManaBarText:Show() end
    PlayerFrameHealthBarText:Hide()
    PlayerFrameManaBarText:Hide()
    TargetFrameTextureFrameHealthBarText:Hide()
    TargetFrameTextureFrameManaBarText:Hide()
    FocusFrameTextureFrameHealthBarText:Hide()
    FocusFrameTextureFrameManaBarText:Hide()
end

local function whoa_cvarUpdate()
    if GetCVarBool("fullSizeFocusFrame") then
        FocusFrameTextureFrameName:SetPoint("BOTTOMRIGHT", FocusFrame, "TOP", 0, -20)
    else
        FocusFrameTextureFrameName:SetPoint("BOTTOMRIGHT", FocusFrame, "TOP", 10, -20)
    end
    whoa_unitText("player")
    whoa_unitText("target")
    whoa_unitText("focus")
end

---------------------------------------------------
-- EVENTS
---------------------------------------------------
local w = CreateFrame("Frame")
w:RegisterEvent("PLAYER_ENTERING_WORLD")
w:RegisterEvent("PLAYER_REGEN_ENABLED")
w:RegisterEvent("PLAYER_TARGET_CHANGED")
w:RegisterEvent("PLAYER_FOCUS_CHANGED")
w:RegisterEvent("CVAR_UPDATE")
w:RegisterEvent("UNIT_HEALTH")
w:RegisterEvent("UNIT_POWER")
if config.classColorParty then
    w:RegisterEvent("PARTY_MEMBERS_CHANGED")
end
function w:OnEvent(event, ...)
--  DEFAULT_CHAT_FRAME:AddMessage(event)
    if event == "PLAYER_ENTERING_WORLD" then
        SlashCmdList['RELOAD'] = function() ReloadUI() end
        SLASH_RELOAD1 = '/rl'
        whoa_playerFrame()
        whoa_targetFrame()
        whoa_focusFrame()
        whoa_cvarUpdate()
        whoa_unitText("player")
    elseif event == "PLAYER_REGEN_ENABLED" then
        whoa_playerFrame()
    elseif event == "PLAYER_TARGET_CHANGED" then
        whoa_targetChanged()
		whoa_targetoftargetFrame()
        whoa_unitText("target")
    elseif event == "PLAYER_FOCUS_CHANGED" then
        whoa_focustargetFrame()
		whoa_focusChanged()
        whoa_unitText("focus")
    elseif event == "UNIT_HEALTH" or event == "UNIT_POWER" then
        local arg1 = ...
        whoa_unitText(arg1)
    elseif event == "CVAR_UPDATE" then
        whoa_cvarUpdate()
    elseif event == "PARTY_MEMBERS_CHANGED" then
        whoa_partyMembersChanged()
		whoa_partyFrame()
    end
end
w:SetScript("OnEvent", w.OnEvent)
	
	---[[Necrotic Strike Tracker]]---
	
		TargetFrame.nt = _G["NecroticOverlayFrame"] or CreateFrame("frame", "NecroticOverlayFrame")
        TargetFrame.NecroticOverlay = TargetFrame.healthbar:CreateTexture(nil, "OVERLAY")
        TargetFrame.NecroticOverlay:SetAllPoints(TargetFrame.healthbar)
        TargetFrame.NecroticOverlay:SetTexture(1, 1, 1, 1)
        TargetFrame.NecroticOverlay:SetBlendMode("BLEND")
        TargetFrame.NecroticOverlay:SetVertexColor(0, 0, 0, 0.4)
        TargetFrame.NecroticOverlay:Hide()
        TargetFrame.nt.bar = TargetFrame.healthbar
        
        TargetFrame.nt:RegisterEvent("UNIT_AURA")
        TargetFrame.nt:RegisterEvent("PLAYER_TARGET_CHANGED")
        TargetFrame.nt:RegisterEvent("COMBAT_EVENT_UNFILTERED")
        TargetFrame.nt:SetScript("OnEvent", function(self, ...)
            TargetFrame.NecroticOverlay:Hide()
            local i = 1
            while true do
                local _, _, texture, _, _, _, _, _, _, _, spellId = UnitAura("target", i, "HARMFUL")
                if not texture then break end
                if spellId == 73975 then
                    if not NecroticStrikeTooltip then
                        NecroticStrikeTooltip = CreateFrame("GameTooltip", "NecroticStrikeTooltip", nil, "GameTooltipTemplate")
                        NecroticStrikeTooltip:SetOwner(WorldFrame, "ANCHOR_NONE")
                    end
                    NecroticStrikeTooltip:ClearLines()
                    NecroticStrikeTooltip:SetUnitDebuff("target", i)
                    self.NecroAbsorb = tonumber(string.match(_G[NecroticStrikeTooltip:GetName() .. "TextLeft2"]:GetText(), "(%d+%s?) .*"))
                    if self.NecroAbsorb > 0 then
                        local currHealth = self.bar:GetValue()
                        local maxHealth = select(2, self.bar:GetMinMaxValues())
                        local lOfs = (self.bar:GetWidth() * (currHealth / maxHealth)) - (self.bar:GetWidth() * (self.NecroAbsorb / maxHealth))
                        local rOfs = (self.bar:GetWidth() * (currHealth / maxHealth)) - self.bar:GetWidth()
                        if lOfs < 0 then lOfs = 0 end
                        if rOfs > 0 then rOfs = 0 end
                        TargetFrame.NecroticOverlay:ClearAllPoints()
                        TargetFrame.NecroticOverlay:SetPoint("LEFT", lOfs, 0)
                        TargetFrame.NecroticOverlay:SetPoint("RIGHT", rOfs, 0)
                        TargetFrame.NecroticOverlay:SetPoint("TOP", 0, 0)
                        TargetFrame.NecroticOverlay:SetPoint("BOTTOM", 0, 0)
                        local r, g, b = self.bar:GetStatusBarColor()
                        TargetFrame.NecroticOverlay:SetVertexColor(1-r, 1-g, 1-b, 0.4)
                        TargetFrame.NecroticOverlay:Show()
                    else
                        TargetFrame.NecroticOverlay:Hide()
                    end
                end
                i = i + 1
            end
        end)